package com.younike.system.service;

import com.younike.common.core.domain.entity.SysUserGroup;

import java.util.List;

/**
 * 小区管理人员和小区关联Service接口
 *
 * @author elev
 * @date 2021-12-08
 */
public interface ISysUserGroupService
{
    /**
     * 查询小区管理人员和小区关联
     *
     * @param userId 小区管理人员和小区关联主键
     * @return 小区管理人员和小区关联
     */
    public SysUserGroup selectSysUserGroupByUserId(Long userId);

    /**
     * 查询小区管理人员和小区关联列表
     *
     * @param sysUserGroup 小区管理人员和小区关联
     * @return 小区管理人员和小区关联集合
     */
    public List<SysUserGroup> selectSysUserGroupList(SysUserGroup sysUserGroup);

    /**
     * 新增小区管理人员和小区关联
     *
     * @param sysUserGroup 小区管理人员和小区关联
     * @return 结果
     */
    public int insertSysUserGroup(SysUserGroup sysUserGroup);

    /**
     * 修改小区管理人员和小区关联
     *
     * @param sysUserGroup 小区管理人员和小区关联
     * @return 结果
     */
    public int updateSysUserGroup(SysUserGroup sysUserGroup);

    /**
     * 批量删除小区管理人员和小区关联
     *
     * @param userIds 需要删除的小区管理人员和小区关联主键集合
     * @return 结果
     */
    public int deleteSysUserGroupByUserIds(Long[] userIds);

    /**
     * 删除小区管理人员和小区关联信息
     *
     * @param userId 小区管理人员和小区关联主键
     * @return 结果
     */
    public int deleteSysUserGroupByUserId(Long userId);
}
